@@ -20,18 +20,25 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <okteta/abstractbytearraymodel.h>
+#include "abstractbytearraymodel.hpp"
+#include "abstractbytearraymodel_p.hpp"
 
 // lib
-#include "charcodec.h"
-#include "character.h"
+#include "charcodec.hpp"
+#include "character.hpp"
 
 namespace Okteta {
 
-static const int SearchedByteCountSignalLimit = 10000;
+static constexpr int SearchedByteCountSignalLimit = 10000;
+
+AbstractByteArrayModel::AbstractByteArrayModel(AbstractByteArrayModelPrivate* dd, QObject* parent)
+    : QObject(parent)
+    , d_ptr(dd)
+{}
 
 AbstractByteArrayModel::AbstractByteArrayModel(QObject* parent)
     : QObject(parent)
+    , d_ptr(new AbstractByteArrayModelPrivate(this))
 {}
 
 AbstractByteArrayModel::~AbstractByteArrayModel() = default;
