@@ -20,10 +20,10 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "addressrangetest.h"
+#include "addressrangetest.hpp"
 
 // test object
-#include <addressrange.h>
+#include <addressrange.hpp>
 // Qt
 #include <QTest>
 
@@ -32,10 +32,10 @@
 namespace Okteta {
 
 // local variables
-static const Address Start = 15;
-static const Address End = 27;
+static constexpr Address Start = 15;
+static constexpr Address End = 27;
 
-static const Size Width = End - Start + 1;
+static constexpr Size Width = End - Start + 1;
 
 void AddressRangeTest::testConstructorByEnd()
 {
