@@ -20,25 +20,29 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "abstractbytearrayview_p.h"
+#include "abstractbytearrayview_p.hpp"
 
 // lib
-#include "controller/knavigator.h"
-#include "controller/kchareditor.h"
-#include "controller/dropper.h"
-#include "controller/mousenavigator.h"
-#include "controller/mousepaster.h"
-#include "controller/zoomwheelcontroller.h"
-#include "widgetcolumnstylist.h"
-#include "kcursor.h"
-#include "bordercolumnrenderer.h"
-#include "oktetagui.h"
+#include "controller/undoredocontroller.hpp"
+#include "controller/clipboardcontroller.hpp"
+#include "controller/keynavigator.hpp"
+#include "controller/chareditor.hpp"
+#include "controller/dropper.hpp"
+#include "controller/mousenavigator.hpp"
+#include "controller/mousepaster.hpp"
+#include "controller/zoomwheelcontroller.hpp"
+#include "widgetcolumnstylist.hpp"
+#include "cursor.hpp"
+#include "bordercolumnrenderer.hpp"
+#include "oktetagui.hpp"
 // Okteta core
-#include <okteta/valuecodec.h>
-#include <okteta/bookmarkable.h>
-#include <okteta/versionable.h>
-#include <okteta/wordbytearrayservice.h>
-#include <okteta/bookmark.h>
+#include <Okteta/ValueCodec>
+#include <Okteta/Bookmarkable>
+#include <Okteta/Versionable>
+#include <Okteta/TextByteArrayAnalyzer>
+#include <Okteta/Bookmark>
+// KF
+#include <KLocalizedString>
 // Qt
 #include <QDragEnterEvent>
 #include <QDragMoveEvent>
@@ -47,22 +51,24 @@
 #include <QApplication>
 #include <QToolTip>
 #include <QMimeData>
+#include <QMenu>
+#include <QIcon>
 #include <QTimer>
 
 namespace Okteta {
 
-static const Address DefaultStartOffset = 0;// 5;
-static const Address DefaultFirstLineOffset = 0;
+static constexpr Address DefaultStartOffset = 0;// 5;
+static constexpr Address DefaultFirstLineOffset = 0;
 
 // zooming is done in steps of font size points
-static const int DefaultZoomStep = 1;
-static const int MinFontPointSize = 4;
-static const int MaxFontPointSize = 128;
+static constexpr int DefaultZoomStep = 1;
+static constexpr int MinFontPointSize = 4;
+static constexpr int MaxFontPointSize = 128;
 
-static const AbstractByteArrayView::ValueCoding DefaultValueCoding =  AbstractByteArrayView::HexadecimalCoding;
-static const AbstractByteArrayView::CharCoding DefaultCharCoding = AbstractByteArrayView::LocalEncoding;
+static constexpr AbstractByteArrayView::ValueCoding DefaultValueCoding =  AbstractByteArrayView::HexadecimalCoding;
+static constexpr AbstractByteArrayView::CharCoding DefaultCharCoding = AbstractByteArrayView::LocalEncoding;
 
-static const AbstractByteArrayView::LayoutStyle DefaultResizeStyle = AbstractByteArrayView::FixedLayoutStyle;
+static constexpr AbstractByteArrayView::LayoutStyle DefaultResizeStyle = AbstractByteArrayView::FixedLayoutStyle;
 
 inline QString octetStreamFormatName() { return QStringLiteral("application/octet-stream"); }
 
@@ -122,11 +128,12 @@ void NullModel::setModified(bool modified)
 Q_GLOBAL_STATIC(NullModel, nullModel)
 
 AbstractByteArrayViewPrivate::AbstractByteArrayViewPrivate(AbstractByteArrayView* parent)
-    : mByteArrayModel(nullModel())
+    : ColumnsViewPrivate(parent)
+    , mByteArrayModel(nullModel())
     , mTableLayout(new ByteArrayTableLayout(DefaultNoOfBytesPerLine, DefaultFirstLineOffset, DefaultStartOffset, 0, 0))
     , mTableCursor(new ByteArrayTableCursor(mTableLayout))
     , mTableRanges(new ByteArrayTableRanges(mTableLayout))
-    , mCursorPixmaps(new KCursor())
+    , mCursorPixmaps(new Cursor())
     , mReadOnly(false)
     , mOverWriteOnly(false)
     , mOverWrite(true)
@@ -135,7 +142,6 @@ AbstractByteArrayViewPrivate::AbstractByteArrayViewPrivate(AbstractByteArrayView
     , mBlinkCursorVisible(false)
     // , mDefaultFontSize( p->font().pointSize() ) crashes in font()
     , mResizeStyle(DefaultResizeStyle)
-    , q_ptr(parent)
 {
 }
 
@@ -150,7 +156,9 @@ AbstractByteArrayViewPrivate::~AbstractByteArrayViewPrivate()
 
     delete mCharEditor;
     delete mValueEditor;
-    delete mNavigator;
+    delete mKeyNavigator;
+    delete mClipboardController;
+    delete mUndoRedoController;
     delete mTabController;
 
     delete mStylist;
@@ -184,10 +192,12 @@ void AbstractByteArrayViewPrivate::init()
     mCharCodec = CharCodec::createCodec((CharCoding)DefaultCharCoding);
     mCharCoding = DefaultCharCoding;
 
-    mTabController = new KTabController(q, nullptr);
-    mNavigator = new KNavigator(q, mTabController);
-    mValueEditor = new KValueEditor(mTableCursor, q, mNavigator);
-    mCharEditor = new KCharEditor(mTableCursor, q, mNavigator);
+    mTabController = new TabController(q, nullptr);
+    mUndoRedoController = new UndoRedoController(q, mTabController);
+    mClipboardController = new ClipboardController(q, mUndoRedoController);
+    mKeyNavigator = new KeyNavigator(q, mClipboardController);
+    mValueEditor = new ValueEditor(mTableCursor, q, mKeyNavigator);
+    mCharEditor = new CharEditor(mTableCursor, q, mKeyNavigator);
 
     mMousePaster = new MousePaster(q, nullptr);
     mMouseNavigator = new MouseNavigator(q, mMousePaster);
@@ -232,15 +242,15 @@ void AbstractByteArrayViewPrivate::setByteArrayModel(AbstractByteArrayModel* byt
 
     Bookmarkable* bookmarks = qobject_cast<Bookmarkable*>(mByteArrayModel);
     if (bookmarks) {
-        q->connect(mByteArrayModel, SIGNAL(bookmarksAdded(QList<Okteta::Bookmark>)),
-                   q, SLOT(onBookmarksChange(QList<Okteta::Bookmark>)));
-        q->connect(mByteArrayModel, SIGNAL(bookmarksRemoved(QList<Okteta::Bookmark>)),
-                   q, SLOT(onBookmarksChange(QList<Okteta::Bookmark>)));
+        QObject::connect(mByteArrayModel, SIGNAL(bookmarksAdded(QVector<Okteta::Bookmark>)),
+                         q, SLOT(onBookmarksChange(QVector<Okteta::Bookmark>)));
+        QObject::connect(mByteArrayModel, SIGNAL(bookmarksRemoved(QVector<Okteta::Bookmark>)),
+                         q, SLOT(onBookmarksChange(QVector<Okteta::Bookmark>)));
     }
     Versionable* versionControl = qobject_cast<Versionable*>(mByteArrayModel);
     if (versionControl) {
-        q->connect(mByteArrayModel, SIGNAL(revertedToVersionIndex(int)),
-                   q, SLOT(onRevertedToVersionIndex(int)));
+        QObject::connect(mByteArrayModel, SIGNAL(revertedToVersionIndex(int)),
+                         q, SLOT(onRevertedToVersionIndex(int)));
     }
 
     q->viewport()->update();
@@ -273,7 +283,7 @@ void AbstractByteArrayViewPrivate::setOffsetCoding(AbstractByteArrayView::Offset
 {
     Q_Q(AbstractByteArrayView);
 
-    const OffsetFormat::Format format = (OffsetFormat::Format)offsetCoding;
+    const OffsetFormat::Format format = static_cast<OffsetFormat::Format>(offsetCoding);
     const OffsetFormat::Format currentFormat = mOffsetColumn->format();
     // no change?
     if (currentFormat == format) {
@@ -620,8 +630,8 @@ bool AbstractByteArrayViewPrivate::selectWord(Address index)
     bool result = false;
 
     if (0 <= index && index < mTableLayout->length()) {
-        const WordByteArrayService WBS(mByteArrayModel, mCharCodec);
-        const AddressRange wordSection = WBS.wordSection(index);
+        const TextByteArrayAnalyzer textAnalyzer(mByteArrayModel, mCharCodec);
+        const AddressRange wordSection = textAnalyzer.wordSection(index);
         if (wordSection.isValid()) {
             const bool oldHasSelection = mTableRanges->hasSelection();
 
@@ -802,7 +812,7 @@ QMimeData* AbstractByteArrayViewPrivate::selectionAsMimeData() const
         return nullptr;
     }
 
-    QMimeData* mimeData = new QMimeData;
+    auto* mimeData = new QMimeData;
     mimeData->setData(octetStreamFormatName(), selectedData());
     return mimeData;
 }
@@ -959,10 +969,10 @@ bool AbstractByteArrayViewPrivate::getNextChangedRange(CoordRange* changedRange,
 
 void AbstractByteArrayViewPrivate::adaptController()
 {
-    KController* controller =
-        isEffectiveReadOnly() ?                                 (KController*)mNavigator :
-        activeCoding() == AbstractByteArrayView::CharCodingId ? (KController*)mCharEditor :
-        (KController*)mValueEditor;
+    AbstractController* controller =
+        isEffectiveReadOnly() ?                                 static_cast<AbstractController*>(mKeyNavigator) :
+        activeCoding() == AbstractByteArrayView::CharCodingId ? static_cast<AbstractController*>(mCharEditor) :
+                                                                static_cast<AbstractController*>(mValueEditor);
     setController(controller);
 }
 
@@ -1027,6 +1037,27 @@ void AbstractByteArrayViewPrivate::unpauseCursor()
     }
 }
 
+QMenu* AbstractByteArrayViewPrivate::createStandardContextMenu(const QPoint& position)
+{
+    Q_UNUSED(position);
+
+    Q_Q(AbstractByteArrayView);
+
+    auto menu = new QMenu(q);
+
+    if (mUndoRedoController->addContextMenuActions(menu) > 0) {
+        menu->addSeparator();
+    }
+
+    if (mClipboardController->addContextMenuActions(menu) > 0) {
+        menu->addSeparator();
+    }
+
+    mKeyNavigator->addContextMenuActions(menu);
+
+    return menu;
+}
+
 void AbstractByteArrayViewPrivate::mousePressEvent(QMouseEvent* mouseEvent)
 {
     Q_Q(AbstractByteArrayView);
@@ -1078,13 +1109,26 @@ bool AbstractByteArrayViewPrivate::event(QEvent* event)
 
     //
     if (event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
+        auto* keyEvent = static_cast<QKeyEvent*>(event);
         if (keyEvent->key() == Qt::Key_Tab || keyEvent->key() == Qt::Key_Backtab) {
             q->keyPressEvent(keyEvent);
             if (keyEvent->isAccepted()) {
                 return true;
             }
         }
+    } else if ((event->type() == QEvent::ContextMenu) &&
+               (static_cast<QContextMenuEvent*>(event)->reason() == QContextMenuEvent::Keyboard)) {
+        ensureCursorVisible();
+
+        const QPoint cursorPos = cursorRect().center();
+        QContextMenuEvent adaptedContextMenuEvent(QContextMenuEvent::Keyboard, cursorPos,
+                                                  q->viewport()->mapToGlobal(cursorPos));
+        adaptedContextMenuEvent.setAccepted(event->isAccepted());
+
+        const bool result = q->ColumnsView::event(&adaptedContextMenuEvent);
+        event->setAccepted(adaptedContextMenuEvent.isAccepted());
+
+        return result;
     }
 
     return q->ColumnsView::event(event);
@@ -1095,7 +1139,7 @@ bool AbstractByteArrayViewPrivate::viewportEvent(QEvent* event)
     Q_Q(AbstractByteArrayView);
 
     if (event->type() == QEvent::ToolTip) {
-        QHelpEvent* helpEvent = static_cast<QHelpEvent*>(event);
+        auto* helpEvent = static_cast<QHelpEvent*>(event);
 
         QString toolTip;
 
@@ -1203,7 +1247,15 @@ void AbstractByteArrayViewPrivate::dropEvent(QDropEvent* dropEvent)
     }
 }
 
-void AbstractByteArrayViewPrivate::onBookmarksChange(const QList<Bookmark>& bookmarks)
+void AbstractByteArrayViewPrivate::contextMenuEvent(QContextMenuEvent* contextMenuEvent)
+{
+    auto menu = createStandardContextMenu(contextMenuEvent->pos());
+    menu->setAttribute(Qt::WA_DeleteOnClose);
+
+    menu->popup(contextMenuEvent->globalPos());
+}
+
+void AbstractByteArrayViewPrivate::onBookmarksChange(const QVector<Bookmark>& bookmarks)
 {
     for (const Bookmark& bookmark : bookmarks) {
         const Address position = bookmark.offset();
