@@ -21,11 +21,11 @@
 #include <QTest>
 #include <QScriptEngine>
 
-#include "view/structures/script/scriptengineinitializer.h"
-#include "view/structures/parsers/scriptvalueconverter.h"
-#include "view/structures/datatypes/topleveldatainformation.h"
-#include "testutils.h"
-#include <okteta/bytearraymodel.h>
+#include "view/structures/script/scriptengineinitializer.hpp"
+#include "view/structures/parsers/scriptvalueconverter.hpp"
+#include "view/structures/datatypes/topleveldatainformation.hpp"
+#include "testutils.hpp"
+#include <Okteta/ByteArrayModel>
 
 class CustomToStringTest : public QObject
 {
@@ -87,7 +87,7 @@ void CustomToStringTest::testUuid()
     QFETCH(QString, uuidString);
     QFETCH(bool, isGUID);
     QScriptEngine* eng = ScriptEngineInitializer::newEngine();
-    ScriptLogger* logger = new ScriptLogger();
+    auto* logger = new ScriptLogger();
     logger->setLogToStdOut(true);
     DataInformation* structure = nullptr;
     if (isGUID) {
