@@ -20,10 +20,10 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "bookmarkstoolfactory.h"
+#include "bookmarkstoolfactory.hpp"
 
 // lib
-#include "bookmarkstool.h"
+#include "bookmarkstool.hpp"
 
 namespace Kasten {
 
@@ -31,7 +31,7 @@ BookmarksToolFactory::BookmarksToolFactory() = default;
 
 BookmarksToolFactory::~BookmarksToolFactory() = default;
 
-AbstractTool* BookmarksToolFactory::create()
+AbstractTool* BookmarksToolFactory::create() const
 {
     return new BookmarksTool();
 }
