@@ -20,13 +20,13 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "statistictablemodel.h"
+#include "statistictablemodel.hpp"
 
 // Okteta core
-#include <okteta/character.h>
-#include <okteta/charcodec.h>
-#include <okteta/valuecodec.h>
-// KF5
+#include <Okteta/Character>
+#include <Okteta/CharCodec>
+#include <Okteta/ValueCodec>
+// KF
 #include <KLocalizedString>
 #include <KColorScheme>
 // Qt
@@ -34,10 +34,10 @@
 
 namespace Kasten {
 
-static const QChar StatisticsDefaultSubstituteChar =  QLatin1Char('.');
-static const QChar StatisticsDefaultUndefinedChar =   QChar(QChar::ReplacementCharacter);
-static const Okteta::ValueCoding DefaultValueCoding =  Okteta::HexadecimalCoding;
-static const int StatisticsByteSetSize = 256;
+static constexpr QChar StatisticsDefaultSubstituteChar =  QLatin1Char('.');
+static constexpr QChar StatisticsDefaultUndefinedChar =   QChar(QChar::ReplacementCharacter);
+static constexpr Okteta::ValueCoding DefaultValueCoding =  Okteta::HexadecimalCoding;
+static constexpr int StatisticsByteSetSize = 256;
 
 StatisticTableModel::StatisticTableModel(int* byteCount, QObject* parent)
     : QAbstractTableModel(parent)
@@ -156,7 +156,7 @@ QVariant StatisticTableModel::data(const QModelIndex& index, int role) const
         case ValueId:
         {
             QString value;
-            mValueCodec->encode(value, 0, byte);
+            mValueCodec->encode(&value, 0, byte);
             result = value;
             break;
         }
