@@ -20,14 +20,14 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "adler32bytearraychecksumalgorithm.h"
+#include "adler32bytearraychecksumalgorithm.hpp"
 
 // Okteta core
-#include <okteta/abstractbytearraymodel.h>
-// KF5
+#include <Okteta/AbstractByteArrayModel>
+// KF
 #include <KLocalizedString>
 
-static const int MOD_ADLER = 65521;
+static constexpr int MOD_ADLER = 65521;
 
 Adler32ByteArrayChecksumAlgorithm::Adler32ByteArrayChecksumAlgorithm()
     : AbstractByteArrayChecksumAlgorithm(
