@@ -20,11 +20,11 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "modsum32bytearraychecksumalgorithm.h"
+#include "modsum32bytearraychecksumalgorithm.hpp"
 
 // Okteta core
-#include <okteta/abstractbytearraymodel.h>
-// KF5
+#include <Okteta/AbstractByteArrayModel>
+// KF
 #include <KLocalizedString>
 // Qt
 #include <QtEndian>
