@@ -7,18 +7,18 @@
 */
 
 //// ADAPT(start)
-//// rename "template_bytearraychecksumparametersetedit.h" to the name of the header of your filter,
-//// e.g. "mybytearraychecksumparametersetedit.h"
-#include "template_bytearraychecksumparametersetedit.h"
+//// rename "template_bytearraychecksumparametersetedit.hpp" to the name of the header of your filter,
+//// e.g. "mybytearraychecksumparametersetedit.hpp"
+#include "template_bytearraychecksumparametersetedit.hpp"
 //// ADAPT(end)
 
 // parameterset
 //// ADAPT(start)
-//// rename "template_bytearraychecksumparameterset.h" to the name of the header of your filter,
-//// e.g. "mybytearraychecksumparameterset.h"
-#include "template_bytearraychecksumparameterset.h"
+//// rename "template_bytearraychecksumparameterset.hpp" to the name of the header of your filter,
+//// e.g. "mybytearraychecksumparameterset.hpp"
+#include "template_bytearraychecksumparameterset.hpp"
 //// ADAPT(end)
-// KF5
+// KF
 #include <KLocalizedString>
 //// ADAPT(start)
 //// add includes for all elements used in the widget
@@ -40,9 +40,9 @@ Template_ByteArrayChecksumParameterSetEdit::Template_ByteArrayChecksumParameterS
 //// setup the widget with all edit fields needed for the parameter set
 //// if there can be invalid states connect the change signals of the edit fields to some slots
 //// where you check if the validity changed
-    QFormLayout* baseLayout = new QFormLayout(this);
+    auto* baseLayout = new QFormLayout(this);
     // margin is provided by the container for this widget
-    baseLayout->setMargin(0);
+    baseLayout->setContentsMargins(0, 0, 0, 0);
 
     mBitNumberEdit = new QSpinBox(this);
     // For demonstration purpose we start at 0, not 1, to show handling of an invalid state
@@ -85,7 +85,7 @@ bool Template_ByteArrayChecksumParameterSetEdit::isValid() const { return mBitNu
 //// also adapt the passing of the values between the parameter set and the edit fields
 void Template_ByteArrayChecksumParameterSetEdit::setParameterSet(const AbstractByteArrayChecksumParameterSet* parameterSet)
 {
-    const Template_ByteArrayChecksumParameterSet* template_ParameterSet =
+    const auto* template_ParameterSet =
         static_cast<const Template_ByteArrayChecksumParameterSet*>(parameterSet);
 
     mBitNumberEdit->setValue(template_ParameterSet->bitNumber());
@@ -93,7 +93,7 @@ void Template_ByteArrayChecksumParameterSetEdit::setParameterSet(const AbstractB
 
 void Template_ByteArrayChecksumParameterSetEdit::getParameterSet(AbstractByteArrayChecksumParameterSet* parameterSet) const
 {
-    Template_ByteArrayChecksumParameterSet* template_ParameterSet =
+    auto* template_ParameterSet =
         static_cast<Template_ByteArrayChecksumParameterSet*>(parameterSet);
 
     template_ParameterSet->setBitNumber(mBitNumberEdit->value());
