@@ -20,10 +20,10 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "poddecodertoolfactory.h"
+#include "poddecodertoolfactory.hpp"
 
 // lib
-#include "poddecodertool.h"
+#include "poddecodertool.hpp"
 
 namespace Kasten {
 
@@ -31,7 +31,7 @@ PodDecoderToolFactory::PodDecoderToolFactory() = default;
 
 PodDecoderToolFactory::~PodDecoderToolFactory() = default;
 
-AbstractTool* PodDecoderToolFactory::create()
+AbstractTool* PodDecoderToolFactory::create() const
 {
     return new PODDecoderTool();
 }
