@@ -20,13 +20,13 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "podtableview.h"
+#include "podtableview.hpp"
 
 // controller
-#include "podtablemodel.h"
-#include "poddelegate.h"
-#include "poddecodertool.h"
-// KF5
+#include "podtablemodel.hpp"
+#include "poddelegate.hpp"
+#include "poddecodertool.hpp"
+// KF
 #include <KComboBox>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -46,7 +46,7 @@ PODTableView::PODTableView(PODDecoderTool* tool, QWidget* parent)
     , mTool(tool)
 {
     QBoxLayout* baseLayout = new QVBoxLayout(this);
-    baseLayout->setMargin(0);
+    baseLayout->setContentsMargins(0, 0, 0, 0);
 
     // table
     mPODTableModel = new PODTableModel(mTool, this);
@@ -74,7 +74,7 @@ PODTableView::PODTableView(PODDecoderTool* tool, QWidget* parent)
 
     // settings
     QBoxLayout* settingsLayout = new QHBoxLayout();
-    settingsLayout->setMargin(0);
+    settingsLayout->setContentsMargins(0, 0, 0, 0);
 
     mByteOrderSelection = new KComboBox(this);
     mByteOrderSelection->addItem(i18nc("@item:inlistbox", "Big-endian"));     // add first for index
