@@ -20,19 +20,20 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "replacetool.h"
+#include "replacetool.hpp"
 
 // controller
-#include "replaceuserqueryable.h"
+#include "replaceuserqueryable.hpp"
 // search controller
-#include "../search/searchjob.h"
-// lib
-#include <kasten/okteta/bytearrayview.h>
-#include <kasten/okteta/bytearraydocument.h>
+#include "../search/searchjob.hpp"
+// Okteta Kasten gui
+#include <Kasten/Okteta/ByteArrayView>
+// Okteta Kasten core
+#include <Kasten/Okteta/ByteArrayDocument>
 // Okteta core
-#include <okteta/charcodec.h>
-#include <okteta/abstractbytearraymodel.h>
-// KF5
+#include <Okteta/CharCodec>
+#include <Okteta/AbstractByteArrayModel>
+// KF
 #include <KLocalizedString>
 // Qt
 #include <QApplication>
@@ -126,12 +127,12 @@ void ReplaceTool::setCaseSensitivity(Qt::CaseSensitivity caseSensitivity)
 //         emit isApplyableChanged( newIsApplyable );
 }
 
-void ReplaceTool::setDoPrompt(int doPrompt)
+void ReplaceTool::setDoPrompt(bool doPrompt)
 {
     mDoPrompt = doPrompt;
 }
 
-void ReplaceTool::replace(KFindDirection direction, bool fromCursor, bool inSelection)
+void ReplaceTool::replace(FindDirection direction, bool fromCursor, bool inSelection)
 {
     mPreviousFound = false;
 
@@ -166,7 +167,7 @@ void ReplaceTool::replace(KFindDirection direction, bool fromCursor, bool inSele
     doReplace(direction, startIndex);
 }
 
-void ReplaceTool::doReplace(KFindDirection direction, Okteta::Address startIndex)
+void ReplaceTool::doReplace(FindDirection direction, Okteta::Address startIndex)
 {
     QApplication::setOverrideCursor(Qt::WaitCursor);
 
