@@ -20,14 +20,14 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "selectrangecontroller.h"
+#include "selectrangecontroller.hpp"
 
 // controller
-#include "selectrangetoolview.h"
-#include "selectrangetool.h"
+#include "selectrangetoolview.hpp"
+#include "selectrangetool.hpp"
 // Kasten gui
-#include <kasten/toolinlineviewable.h>
-// KF5
+#include <Kasten/ToolInlineViewable>
+// KF
 #include <KXMLGUIClient>
 #include <KLocalizedString>
 #include <KActionCollection>
@@ -44,7 +44,7 @@ SelectRangeController::SelectRangeController(If::ToolInlineViewable* toolInlineV
     KActionCollection* actionCollection = guiClient->actionCollection();
 
     mSelectAction = new QAction(QIcon::fromTheme(QStringLiteral("select-rectangular")),
-                                i18nc("@action:inmenu", "&Select range..."), this);
+                                i18nc("@action:inmenu", "&Select Range..."), this);
     connect(mSelectAction, &QAction::triggered, this, &SelectRangeController::select);
     actionCollection->setDefaultShortcut(mSelectAction, Qt::CTRL + Qt::Key_E);
 
@@ -60,6 +60,10 @@ SelectRangeController::SelectRangeController(If::ToolInlineViewable* toolInlineV
 
 SelectRangeController::~SelectRangeController()
 {
+    if (mToolInlineViewable->currentToolInlineView() == mView) {
+        mToolInlineViewable->setCurrentToolInlineView(nullptr);
+    }
+
     delete mView;
     delete mTool;
 }
