@@ -20,9 +20,9 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "containedstringtablemodel.h"
+#include "containedstringtablemodel.hpp"
 
-// KF5
+// KF
 #include <KLocalizedString>
 
 ContainedStringTableModel::ContainedStringTableModel(const QList<ContainedString>* containedStringList,
