@@ -20,15 +20,16 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "viewconfigcontroller.h"
+#include "viewconfigcontroller.hpp"
 
 // lib
-#include "bytesperlinedialog.h"
-#include "bytespergroupdialog.h"
-#include <kasten/okteta/bytearrayview.h>
+#include "bytesperlinedialog.hpp"
+#include "bytespergroupdialog.hpp"
+// Okteta Kasten gui
+#include <Kasten/Okteta/ByteArrayView>
 // Okteta core
-#include <okteta/charcodec.h>
-// KF5
+#include <Okteta/CharCodec>
+// KF
 #include <KXMLGUIClient>
 #include <KLocalizedString>
 #include <KActionCollection>
@@ -205,7 +206,7 @@ void ViewConfigController::setBytesPerLine()
 {
     BytesPerLineDialog dialog;
     dialog.setBytesPerLine(mByteArrayView->noOfBytesPerLine());
-    if (dialog.exec()) {
+    if (dialog.exec() != 0) {
         mByteArrayView->setNoOfBytesPerLine(dialog.bytesPerLine());
 
         // TODO: change should be signalled and the action listen to that
@@ -217,7 +218,7 @@ void ViewConfigController::setBytesPerGroup()
 {
     BytesPerGroupDialog dialog;
     dialog.setGroupedBytesCount(mByteArrayView->noOfGroupedBytes());
-    if (dialog.exec()) {
+    if (dialog.exec() != 0) {
         mByteArrayView->setNoOfGroupedBytes(dialog.groupedBytesCount());
     }
 }
