@@ -20,15 +20,15 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "viewprofilecontroller.h"
+#include "viewprofilecontroller.hpp"
 
 // controller
-#include "viewprofileeditdialog.h"
+#include "viewprofileeditdialog.hpp"
 // Okteta Gui Kasten
-#include <kasten/okteta/bytearrayviewprofilemanager.h>
-#include <kasten/okteta/bytearrayviewprofilesynchronizer.h>
-#include <kasten/okteta/bytearrayview.h>
-// KF5
+#include <Kasten/Okteta/ByteArrayViewProfileManager>
+#include <Kasten/Okteta/ByteArrayViewProfileSynchronizer>
+#include <Kasten/Okteta/ByteArrayView>
+// KF
 #include <KXMLGUIClient>
 #include <KXMLGUIFactory>
 #include <KActionMenu>
@@ -42,8 +42,7 @@ namespace Kasten {
 ViewProfileController::ViewProfileController(ByteArrayViewProfileManager* viewProfileManager,
                                              QWidget* parentWidget,
                                              KXMLGUIClient* guiClient)
-    : AbstractXmlGuiController()
-    , mGuiClient(guiClient)
+    : mGuiClient(guiClient)
     , mViewProfileManager(viewProfileManager)
     , mParentWidget(parentWidget)
 {
@@ -56,21 +55,21 @@ ViewProfileController::ViewProfileController(ByteArrayViewProfileManager* viewPr
     mCreateNewAction =
         new QAction(QIcon::fromTheme(QStringLiteral("document-new")),
                     i18nc("@action:inmenu create a new view profile",
-                          "Create new..."),
+                          "Create New..."),
                     this);
     connect(mCreateNewAction, &QAction::triggered, this, &ViewProfileController::onCreateNewActionTriggered);
 
     mSaveChangesAction =
         new QAction(QIcon::fromTheme(QStringLiteral("document-save")),
                     i18nc("@action:inmenu save changed to the view profile to the base profile",
-                          "Save changes"),
+                          "Save Changes"),
                     this);
     connect(mSaveChangesAction, &QAction::triggered, this, &ViewProfileController::onSaveChangesActionTriggered);
 
     mResetChangesAction =
         new QAction(QIcon::fromTheme(QStringLiteral("document-revert")),
                     i18nc("@action:inmenu reset settings back to those of the saved base profile",
-                          "Reset changes"),
+                          "Reset Changes"),
                     this);
     connect(mResetChangesAction, &QAction::triggered, this, &ViewProfileController::onResetChangesActionTriggered);
 
@@ -141,7 +140,7 @@ void ViewProfileController::onViewProfilesChanged()
 {
     qDeleteAll(mViewProfilesActionGroup->actions());
 
-    const QList<ByteArrayViewProfile> viewProfiles = mViewProfileManager->viewProfiles();
+    const QVector<ByteArrayViewProfile> viewProfiles = mViewProfileManager->viewProfiles();
     const ByteArrayViewProfile::Id currentViewProfileId = mByteArrayViewProfileSynchronizer ?
                                                           mByteArrayViewProfileSynchronizer->viewProfileId() :
                                                           ByteArrayViewProfile::Id();
@@ -153,7 +152,7 @@ void ViewProfileController::onViewProfilesChanged()
     bool isCurrentViewProfileExisting = false;
     for (const ByteArrayViewProfile& viewProfile : viewProfiles) {
         const QString title = viewProfile.viewProfileTitle();
-        QAction* action = new QAction(title, mViewProfilesActionGroup);
+        auto* action = new QAction(title, mViewProfilesActionGroup);
         action->setCheckable(true);
         const ByteArrayViewProfile::Id viewProfileId = viewProfile.id();
         action->setData(viewProfileId);
@@ -188,7 +187,7 @@ void ViewProfileController::onLocalSyncStateChanged(Kasten::LocalSyncState local
 
 void ViewProfileController::onCreateNewActionTriggered()
 {
-    ViewProfileEditDialog* dialog = new ViewProfileEditDialog(mParentWidget);
+    auto* dialog = new ViewProfileEditDialog(mParentWidget);
     const QString dialogTitle = i18nc("@window:title",
                                       "New View Profile");
     dialog->setWindowTitle(dialogTitle);
@@ -213,7 +212,7 @@ void ViewProfileController::onCreateNewActionTriggered()
     const int answer = dialog->exec();
 
     if (answer == QDialog::Accepted) {
-        QList<ByteArrayViewProfile> viewProfiles {
+        QVector<ByteArrayViewProfile> viewProfiles {
             dialog->viewProfile()
         };
         mViewProfileManager->saveViewProfiles(viewProfiles);
