@@ -20,12 +20,12 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "viewprofileeditdialog.h"
+#include "viewprofileeditdialog.hpp"
 
 // lib
-#include "viewprofileedit.h"
+#include "viewprofileedit.hpp"
 // Okteta Gui Kasten
-#include <kasten/okteta/bytearrayviewprofile.h>
+#include <Kasten/Okteta/ByteArrayViewProfile>
 // Qt
 #include <QVBoxLayout>
 #include <QPushButton>
@@ -45,7 +45,7 @@ ViewProfileEditDialog::ViewProfileEditDialog(QWidget* parent)
     connect(dialogButtonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
     // main layout
-    QVBoxLayout* layout = new QVBoxLayout;
+    auto* layout = new QVBoxLayout;
     layout->addWidget(mViewProfileEdit);
     layout->addStretch();
     layout->addWidget(dialogButtonBox);
