@@ -20,13 +20,13 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "viewprofilesmanagecontroller.h"
+#include "viewprofilesmanagecontroller.hpp"
 
 // Okteta Gui Kasten
-#include <kasten/okteta/bytearrayviewprofilemanager.h>
+#include <Kasten/Okteta/ByteArrayViewProfileManager>
 // controller
-#include "viewprofilesmanagedialog.h"
-// KF5
+#include "viewprofilesmanagedialog.hpp"
+// KF
 #include <KXMLGUIClient>
 #include <KLocalizedString>
 #include <KActionCollection>
@@ -56,7 +56,7 @@ void ViewProfilesManageController::setTargetModel(AbstractModel* model)
 
 void ViewProfilesManageController::manageProfiles()
 {
-    ViewProfilesManageDialog* dialog = new ViewProfilesManageDialog(mViewProfileManager, mParentWidget);
+    auto* dialog = new ViewProfilesManageDialog(mViewProfileManager, mParentWidget);
     dialog->exec();
 
     delete dialog;
