@@ -20,14 +20,14 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "bytearrayvaluesstreamencoder.h"
+#include "bytearrayvaluesstreamencoder.hpp"
 
 // lib
-#include <bytearrayview.h>
+#include <bytearrayview.hpp>
 // Okteta core
-#include <okteta/abstractbytearraymodel.h>
-#include <okteta/valuecodec.h>
-// KF5
+#include <Okteta/AbstractByteArrayModel>
+#include <Okteta/ValueCodec>
+// KF
 #include <KLocalizedString>
 // Qt
 #include <QTextStream>
@@ -70,7 +70,7 @@ bool ByteArrayValuesStreamEncoder::encodeDataToStream(QIODevice* device,
             textStream << mSettings.separation;
         }
 
-        valueCodec->encode(valueString, 0, byteArrayModel->byte(i));
+        valueCodec->encode(&valueString, 0, byteArrayModel->byte(i));
 
         textStream << valueString;
     }
