@@ -20,13 +20,13 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "addressvalidator.h"
+#include "addressvalidator.hpp"
 
 // lib
-#include <oktetakastengui.h>
+#include <oktetakastengui.hpp>
 // Okteta core
-#include <okteta/valuecodec.h>
-// KF5
+#include <Okteta/ValueCodec>
+// KF
 #include <KLocalizedString>
 // Qt
 #include <QString>
@@ -140,7 +140,7 @@ Address AddressValidator::toAddress(const QString& string, AddressType* addressT
 QString AddressValidator::toString(Address address, AddressType addressType) const
 {
     // ExpressionCoding just uses base 10 so no need to adjust this code
-    const int isHexadecimal = (mCodecId == HexadecimalCoding);
+    const bool isHexadecimal = (mCodecId == HexadecimalCoding);
     const int base = isHexadecimal ? 16 : 10;
 
     QString string = QString::number(address, base);
