@@ -20,8 +20,8 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "bytearraycombobox.h"
-#include "bytearraycombobox_p.h"
+#include "bytearraycombobox.hpp"
+#include "bytearraycombobox_p.hpp"
 
 namespace Okteta {
 
@@ -34,10 +34,7 @@ ByteArrayComboBox::ByteArrayComboBox(QWidget* parent)
     d->init();
 }
 
-ByteArrayComboBox::~ByteArrayComboBox()
-{
-    delete d_ptr;
-}
+ByteArrayComboBox::~ByteArrayComboBox() = default;
 
 void ByteArrayComboBox::setByteArray(const QByteArray& byteArray)
 {
