@@ -20,11 +20,11 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "bytearrayjanusview.h"
+#include "bytearrayjanusview.hpp"
 
 // Okteta gui
-#include <okteta/bytearraycolumnview.h>
-#include <okteta/bytearrayrowview.h>
+#include <Okteta/ByteArrayColumnView>
+#include <Okteta/ByteArrayRowView>
 // Qt
 #include <QLayout>
 #include <QScrollBar>
@@ -35,7 +35,7 @@ ByteArrayJanusView::ByteArrayJanusView(QWidget* parent)
     : QWidget(parent)
 {
     mLayout = new QHBoxLayout(this);
-    mLayout->setMargin(0);
+    mLayout->setContentsMargins(0, 0, 0, 0);
     setViewModus(ColumnViewId);
 }
 
@@ -95,6 +95,9 @@ void ByteArrayJanusView::setViewModus(int viewModus)
     }
     mViewModus = viewModus;
 
+    mView->setContextMenuPolicy(Qt::CustomContextMenu);
+    connect(mView, &QWidget::customContextMenuRequested, this, &ByteArrayJanusView::viewContextMenuRequested);
+
     connect(mView, &AbstractByteArrayView::hasSelectedDataChanged, this, &ByteArrayJanusView::hasSelectedDataChanged);
     connect(mView, &AbstractByteArrayView::selectionChanged, this, &ByteArrayJanusView::selectionChanged);
     connect(mView, &AbstractByteArrayView::readOnlyChanged, this, &ByteArrayJanusView::readOnlyChanged);
@@ -175,7 +178,12 @@ Address ByteArrayJanusView::cursorPosition() const
 }
 QRect ByteArrayJanusView::cursorRect() const
 {
-    return mView->cursorRect();
+    // Okteta Gui uses viewport coordinates like QTextEdit,
+    // but here view coordinates are used, so map the rect as needed
+    QRect cursorRect = mView->cursorRect();
+    const QPoint viewTopLeft = mView->viewport()->mapToParent(cursorRect.topLeft());
+    cursorRect.moveTopLeft(viewTopLeft);
+    return cursorRect;
 }
 
 void ByteArrayJanusView::setStartOffset(Address startOffset)
