@@ -20,19 +20,19 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "exportcontroller.h"
+#include "exportcontroller.hpp"
 
 // lib
-#include "exportdialog.h"
+#include "exportdialog.hpp"
 // Kasten gui
-#include <kasten/modelcodecviewmanager.h>
-#include <kasten/dataselectable.h>
-#include <kasten/abstractmodelexporterconfigeditor.h>
+#include <Kasten/ModelCodecViewManager>
+#include <Kasten/DataSelectable>
+#include <Kasten/AbstractModelExporterConfigEditor>
 // Kasten core
-#include <kasten/modelcodecmanager.h>
-#include <kasten/abstractdocument.h>
-#include <kasten/abstractmodelexporter.h>
-// KF5
+#include <Kasten/ModelCodecManager>
+#include <Kasten/AbstractDocument>
+#include <Kasten/AbstractModelExporter>
+// KF
 #include <KXMLGUIClient>
 #include <KXMLGUIFactory>
 #include <KActionCollection>
@@ -46,8 +46,7 @@ namespace Kasten {
 ExportController::ExportController(ModelCodecViewManager* modelCodecViewManager,
                                    ModelCodecManager* modelCodecManager,
                                    KXMLGUIClient* guiClient)
-    : AbstractXmlGuiController()
-    , mModelCodecViewManager(modelCodecViewManager)
+    : mModelCodecViewManager(modelCodecViewManager)
     , mModelCodecManager(modelCodecManager)
 {
     mExportSelectAction = new KSelectAction(QIcon::fromTheme(QStringLiteral("document-export")),
@@ -85,14 +84,14 @@ void ExportController::updateActions()
 
     const AbstractModelSelection* selection = mSelectionControl ? mSelectionControl->modelSelection() : nullptr;
 
-    const QList<AbstractModelExporter*> exporterList =
+    const QVector<AbstractModelExporter*> exporterList =
         mModelCodecManager->exporterList(mModel, selection);
-    const bool hasExporters = (exporterList.size() > 0);
+    const bool hasExporters = (!exporterList.isEmpty());
 
     if (hasExporters) {
         for (auto* exporter : exporterList) {
             const QString title = exporter->remoteTypeName();
-            QAction* action = new QAction(title, mExportSelectAction);
+            auto* action = new QAction(title, mExportSelectAction);
 
             action->setData(QVariant::fromValue(exporter));
             mExportSelectAction->addAction(action);
@@ -108,7 +107,7 @@ void ExportController::updateActions()
 
 void ExportController::onActionTriggered(QAction* action)
 {
-    AbstractModelExporter* exporter = action->data().value<AbstractModelExporter*>();
+    auto* exporter = action->data().value<AbstractModelExporter*>();
 
     const AbstractModelSelection* selection = mSelectionControl ? mSelectionControl->modelSelection() : nullptr;
 
@@ -118,7 +117,7 @@ void ExportController::onActionTriggered(QAction* action)
     if (configEditor) {
         ExportDialog* dialog = new ExportDialog(exporter->remoteTypeName(), configEditor);
         dialog->setData(mModel, selection);
-        if (!dialog->exec()) {
+        if (dialog->exec() == 0) {
             return;
         }
     }
