@@ -20,20 +20,20 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "insertcontroller.h"
+#include "insertcontroller.hpp"
 
 // lib
-#include "insertdialog.h"
+#include "insertdialog.hpp"
 // Kasten gui
-#include <kasten/modelcodecviewmanager.h>
-#include <kasten/selecteddatawriteable.h>
-#include <kasten/abstractmodeldatageneratorconfigeditor.h>
+#include <Kasten/ModelCodecViewManager>
+#include <Kasten/SelectedDataWriteable>
+#include <Kasten/AbstractModelDataGeneratorConfigEditor>
 // Kasten core
-#include <kasten/modeldatageneratethread.h>
-#include <kasten/modelcodecmanager.h>
-#include <kasten/abstractmodeldatagenerator.h>
-#include <kasten/abstractmodel.h>
-// KF5
+#include <Kasten/ModelDataGenerateThread>
+#include <Kasten/ModelCodecManager>
+#include <Kasten/AbstractModelDataGenerator>
+#include <Kasten/AbstractModel>
+// KF
 #include <KXMLGUIClient>
 #include <KXMLGUIFactory>
 #include <KActionCollection>
@@ -43,8 +43,8 @@
 #include <QMimeData>
 #include <QApplication>
 
-#ifndef ABSTRACTMODELDATAGENERATOR_METATYPE
-#define ABSTRACTMODELDATAGENERATOR_METATYPE
+#ifndef KASTEN_ABSTRACTMODELDATAGENERATOR_METATYPE
+#define KASTEN_ABSTRACTMODELDATAGENERATOR_METATYPE
 Q_DECLARE_METATYPE(Kasten::AbstractModelDataGenerator*)
 #endif
 
@@ -53,8 +53,7 @@ namespace Kasten {
 InsertController::InsertController(ModelCodecViewManager* modelCodecViewManager,
                                    ModelCodecManager* modelCodecManager,
                                    KXMLGUIClient* guiClient)
-    : AbstractXmlGuiController()
-    , mModelCodecViewManager(modelCodecViewManager)
+    : mModelCodecViewManager(modelCodecViewManager)
     , mModelCodecManager(modelCodecManager)
 {
     mInsertSelectAction = new KSelectAction(i18nc("@title:menu", "Insert"), this);
@@ -94,14 +93,14 @@ void InsertController::updateActions()
     // TODO: pass model to find which mimetypes it can read
     // mSelectedDataWriteableControl->canReadData( QMimeData() ) needs already data
     // TODO: it this depend on the current selection/focus? So it needs to be updated on every change?
-    const QList<AbstractModelDataGenerator*> generatorList =
+    const QVector<AbstractModelDataGenerator*> generatorList =
         mModelCodecManager->generatorList();
-    const bool hasGenerators = (generatorList.size() > 0);
+    const bool hasGenerators = (!generatorList.isEmpty());
 
     if (hasGenerators) {
         for (AbstractModelDataGenerator* generator : generatorList) {
             const QString title = generator->typeName();
-            QAction* action = new QAction(title, mInsertSelectAction);
+            auto* action = new QAction(title, mInsertSelectAction);
 
             action->setData(QVariant::fromValue(generator));
             mInsertSelectAction->addAction(action);
@@ -119,23 +118,22 @@ void InsertController::updateActions()
 
 void InsertController::onActionTriggered(QAction* action)
 {
-    AbstractModelDataGenerator* generator = action->data().value<AbstractModelDataGenerator*>();
+    auto* generator = action->data().value<AbstractModelDataGenerator*>();
 
     AbstractModelDataGeneratorConfigEditor* configEditor =
         mModelCodecViewManager->createConfigEditor(generator);
 
     if (configEditor) {
-        InsertDialog* dialog = new InsertDialog(configEditor);
+        auto* dialog = new InsertDialog(configEditor);
 //         dialog->setData( mModel, selection ); TODO
-        if (!dialog->exec()) {
+        if (dialog->exec() == 0) {
             return;
         }
     }
 
     QApplication::setOverrideCursor(Qt::WaitCursor);
 
-    ModelDataGenerateThread* generateThread =
-        new ModelDataGenerateThread(this, generator);
+    auto* generateThread = new ModelDataGenerateThread(this, generator);
     generateThread->start();
     while (!generateThread->wait(100)) {
         QCoreApplication::processEvents(QEventLoop::ExcludeUserInputEvents | QEventLoop::ExcludeSocketNotifiers);
