@@ -20,13 +20,13 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "zoomslider.h"
+#include "zoomslider.hpp"
 
 // Kasten gui
-#include <kasten/zoomable.h>
+#include <Kasten/Zoomable>
 // Kasten core
-#include <kasten/abstractmodel.h>
-// KF5
+#include <Kasten/AbstractModel>
+// KF
 #include <KLocalizedString>
 // Qt
 #include <QSlider>
@@ -37,7 +37,7 @@
 
 namespace Kasten {
 
-static const int ZoomSliderWidth = 150;
+static constexpr int ZoomSliderWidth = 150;
 
 // TODO: look at Dolphin/Krita/KOffice zoom tool
 
@@ -57,9 +57,9 @@ ZoomSlider::ZoomSlider(QWidget* parent)
     mZoomInButton->setIcon(QIcon::fromTheme(QStringLiteral("zoom-in")));
     mZoomInButton->setAutoRaise(true);
 
-    QHBoxLayout* layout = new QHBoxLayout(this);
+    auto* layout = new QHBoxLayout(this);
     layout->setSpacing(0);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(mZoomOutButton);
     layout->addWidget(mSlider);
     layout->addWidget(mZoomInButton);
