@@ -20,21 +20,17 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "abstractmodelselection.h"
+#include "abstractmodelselection.hpp"
 
 namespace Kasten {
 
-class Q_DECL_HIDDEN AbstractModelSelection::Private
+class AbstractModelSelectionPrivate
 {
 };
 
-AbstractModelSelection::AbstractModelSelection()
-    : d(new Private())
-{}
 
-AbstractModelSelection::~AbstractModelSelection()
-{
-    delete d;
-}
+AbstractModelSelection::AbstractModelSelection() = default;
+
+AbstractModelSelection::~AbstractModelSelection() = default;
 
 }
