@@ -20,12 +20,13 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "singleviewarea_p.h"
+#include "singleviewarea_p.hpp"
 
 // lib
-#include "toolinlineviewwidget.h"
-#include <abstracttoolinlineview.h>
-#include <kasten/abstractdocument.h>
+#include "toolinlineviewwidget.hpp"
+#include <abstracttoolinlineview.hpp>
+// Kasten core
+#include <Kasten/AbstractDocument>
 
 namespace Kasten {
 
@@ -54,21 +55,14 @@ void SingleViewAreaPrivate::init()
 
 void SingleViewAreaPrivate::setCurrentToolInlineView(AbstractToolInlineView* view)
 {
-    ToolInlineViewWidget* currentViewWidget =
-        qobject_cast<ToolInlineViewWidget*>(mViewAreaBox->bottomWidget());
-    AbstractToolInlineView* currentToolInlineView =
-        currentViewWidget ? currentViewWidget->view() : nullptr;
-
-    if (currentToolInlineView != view) {
-        ToolInlineViewWidget* toolInlineViewWidget =
-            view ? new ToolInlineViewWidget(view /*->widget()*/) : nullptr;
-        mViewAreaBox->setBottomWidget(toolInlineViewWidget);
+    if (mCurrentToolInlineView != view) {
+        mCurrentToolInlineView = view;
+        QWidget* toolInlineViewWidget = mCurrentToolInlineView ? mCurrentToolInlineView->widget() : nullptr;
+        mViewAreaBox->setBottomToolWidget(toolInlineViewWidget);
     }
 
-    if (view) {
-        view->widget()->setFocus();
-    } else if (mCurrentView) {
-        mCurrentView->setFocus();
+    if (mCurrentToolInlineView) {
+        mViewAreaBox->showBottomToolWidget();
     }
 }
 
