@@ -20,18 +20,18 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "about.h"
+#include "about.hpp"
 
-// KF5
+// KF
 #include <KLocalizedString>
 
 OktetaAboutData::OktetaAboutData()
     : KAboutData(QStringLiteral("okteta"),
                  i18n("Okteta"), // name
-                 QStringLiteral("0.25.5"),
+                 QStringLiteral(OKTETA_VERSION),
                  i18n("Hex editor"), // description
                  KAboutLicense::GPL_V2,
-                 i18n("Copyright 2006-2018 Friedrich W. H. Kossebau"), // copyright
+                 i18n("Copyright 2006-2019 Friedrich W. H. Kossebau"), // copyright
                  i18n("Edit the raw data of files"), // comment
                  QStringLiteral("https://userbase.kde.org/Okteta"))
 {
